==> last.fm-1.3.2.13.src.tar.bz2: last.fm-1.3.2.13/src/systray.h <==
/***************************************************************************
 *   Copyright (C) 2005 - 2007 by                                          *
 *      Christian Muehlhaeuser, Last.fm Ltd <chris@last.fm>                *
 *      Erik Jaelevik, Last.fm Ltd <erik@last.fm>                          *
 *      Max Howell, Last.fm Ltd <max@last.fm>                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA  02111-1307, USA.          *
 ***************************************************************************/

#ifndef SYS_TRAY_H
#define SYS_TRAY_H

#include "lastfmtools_common.h"

#include <QPixmap>
#include <QString>
#include <QSystemTrayIcon>

class QMenu;


/*************************************************************************/ /**
    A thin wrapper around the TrayIcon class to deal with application-
    specific tray stuff.
******************************************************************************/
class SysTray : public QObject
{
    Q_OBJECT

    public:
        SysTray( Container* parent );

    public slots:
        void show() { m_trayIcon->show(); }

        void setUser( UserSettings& currentUser );
        void setTrack( const MetaData &track );
        void setToolTip( const QString& tooltip ) { m_trayIcon->setToolTip( tooltip ); }

    private:
        void refreshToolTip();

        QSystemTrayIcon *m_trayIcon;
        
        #ifdef Q_WS_MAC
        QPixmap m_pixmap;
        QPixmap m_inverted_pixmap;
        #endif

        QMenu* m_trayMenu;
        QMenu* m_userMenu;
		#ifdef Q_WS_MAC
			Container* m_macParent;
		#endif

        QString m_artist;
        QString m_track;
        QString m_user;

    private slots:
        void aboutToShowMenu();
        void aboutToHideMenu();

        void trayAction( QSystemTrayIcon::ActivationReason reason );
};

#endif // SYSTRAY_H

==> last.fm-1.5.4.26862.src.tar.bz2: last.fm-1.5.4.26862/src/systray.h <==
/***************************************************************************
 *   Copyright (C) 2005 - 2007 by                                          *
 *      Christian Muehlhaeuser, Last.fm Ltd <chris@last.fm>                *
 *      Erik Jaelevik, Last.fm Ltd <erik@last.fm>                          *
 *      Max Howell, Last.fm Ltd <max@last.fm>                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA  02110-1301, USA.          *
 ***************************************************************************/

#ifndef SYS_TRAY_H
#define SYS_TRAY_H

#include <QSystemTrayIcon>
#include <QTimer>


class TrayIcon : public QSystemTrayIcon
{
    Q_OBJECT

public:
    TrayIcon( QObject* parent );
    void startIpodScrobblingAnimation();
    void stopIpodScrobblingAnimation();

public slots:
    void setTrack( const class MetaData &track );
    void setUser( class LastFmUserSettings& currentUser );

private:
    void refreshToolTip();

  #ifdef Q_WS_MAC
    QPixmap m_pixmap;
  #endif
    
    QTimer m_animationTimer;
    QString m_artist;
    QString m_track;
    QString m_user;

    QList<QPixmap> m_animationPixmaps;
    int m_currentAnimationFrame;

private slots:
    void onAnimationTimer();
};

#endif // SYSTRAY_H
